@@ -7,7 +7,7 @@ use 5.008;
 
 use vars qw($VERSION);
 
-$VERSION = '0.2.9';
+$VERSION = '0.2.10';
 
 1; # End of XML::CompareML
 
@@ -63,7 +63,7 @@ an XML:CompareML::DocBook object.
 
 =head1 AUTHOR
 
-Shlomi Fish, C<< <shlomif@iglu.org.il> >>
+Shlomi Fish, L<http://www.shlomifish.org/> .
 
 =head1 BUGS
 
